diff --git a/doc/man/en/linkcheckerrc.5 b/doc/man/en/linkcheckerrc.5
index 630d0392..48944923 100644
--- a/doc/man/en/linkcheckerrc.5
+++ b/doc/man/en/linkcheckerrc.5
@@ -174,7 +174,7 @@ Command line option: \fB\-\-check\-extern\fP
.TP
\fBentry=\fP\fIREGEX\fP \fIUSER\fP [\fIPASS\fP] (\fI\%MULTILINE\fP)
Provide individual username/password pairs for different links. In
-addtion to a single login page specified with \fBloginurl\fP multiple
+addition to a single login page specified with \fBloginurl\fP multiple
FTP, HTTP (Basic Authentication) and telnet links are supported.
Entries are a triple (URL regex, username, password) or a tuple (URL
regex, username), where the entries are separated by whitespace.
diff --git a/linkcheck/checker/__init__.py b/linkcheck/checker/__init__.py
index 952f6997..f2be0482 100644
--- a/linkcheck/checker/__init__.py
+++ b/linkcheck/checker/__init__.py
@@ -116,7 +116,7 @@ def get_url_from(
else:
scheme = None
if not (url or name):
- # use filename as base url, with slash as path seperator
+ # use filename as base url, with slash as path separator
name = base_url.replace("\\", "/")
allowed_schemes = aggregate.config["allowedschemes"]
# ignore local PHP files with execution directives
diff --git a/linkcheck/checker/nntpurl.py b/linkcheck/checker/nntpurl.py
index 1b504867..9479c759 100644
--- a/linkcheck/checker/nntpurl.py
+++ b/linkcheck/checker/nntpurl.py
@@ -55,7 +55,7 @@ class NntpUrl(urlbase.UrlBase):
number = nntp.stat("<" + group + ">")[1]
self.add_info(_('Article number %(num)s found.') % {"num": number})
else:
- # split off trailing articel span
+ # split off trailing article span
group = group.split('/', 1)[0]
if group:
# request group info (resp, count, first, last, name)
diff --git a/linkcheck/checker/urlbase.py b/linkcheck/checker/urlbase.py
index 8d0bede0..0fadddb4 100644
--- a/linkcheck/checker/urlbase.py
+++ b/linkcheck/checker/urlbase.py
@@ -224,7 +224,7 @@ class UrlBase:
# This the real url we use when checking so it also referred to
# as 'real url'
self.url = None
- # a splitted version of url for convenience
+ # a split version of url for convenience
self.urlparts = None
# the scheme, host, port and anchor part of url
self.scheme = self.host = self.port = self.anchor = None
@@ -690,7 +690,7 @@ class UrlBase:
pass
def can_get_content(self):
- """Indicate wether url get_content() can be called."""
+ """Indicate whether url get_content() can be called."""
return self.size <= self.aggregate.config["maxfilesizedownload"]
def download_content(self):
@@ -956,6 +956,6 @@ class CompactUrlData:
__slots__ = urlDataAttr
def __init__(self, wired_url_data):
- '''Set all attributes according to the dictionnary wired_url_data'''
+ '''Set all attributes according to the dictionary wired_url_data'''
for attr in urlDataAttr:
setattr(self, attr, wired_url_data[attr])
diff --git a/linkcheck/decorators.py b/linkcheck/decorators.py
index 399d8b85..a66abe1b 100644
--- a/linkcheck/decorators.py
+++ b/linkcheck/decorators.py
@@ -112,7 +112,7 @@ def synchronize(lock, func, log_duration_secs=0):
def synchronized(lock):
- """A decorator calling a function with aqcuired lock."""
+ """A decorator calling a function with acquired lock."""
return lambda func: synchronize(lock, func)
diff --git a/linkcheck/director/__init__.py b/linkcheck/director/__init__.py
index 6bed0216..3d486ba4 100644
--- a/linkcheck/director/__init__.py
+++ b/linkcheck/director/__init__.py
@@ -68,7 +68,7 @@ def check_urls(aggregate):
console.internal_error()
aggregate.logger.log_internal_error()
abort(aggregate)
- # Not catched exceptions at this point are SystemExit and GeneratorExit,
+ # Not caught exceptions at this point are SystemExit and GeneratorExit,
# and both should be handled by the calling layer.
diff --git a/linkcheck/fileutil.py b/linkcheck/fileutil.py
index cc39342d..eb9bb91e 100644
--- a/linkcheck/fileutil.py
+++ b/linkcheck/fileutil.py
@@ -94,7 +94,7 @@ def is_readable(filename):
def is_accessable_by_others(filename):
- """Check if file is group or world accessable."""
+ """Check if file is group or world accessible."""
mode = os.stat(filename)[stat.ST_MODE]
return mode & (stat.S_IRWXG | stat.S_IRWXO)
diff --git a/linkcheck/ftpparse.py b/linkcheck/ftpparse.py
index b6eff909..80a2d396 100644
--- a/linkcheck/ftpparse.py
+++ b/linkcheck/ftpparse.py
@@ -74,7 +74,7 @@ def ftpparse(line):
# Also produced by Microsoft's FTP servers for Windows:
# "---------- 1 owner group 1803128 Jul 10 10:18 ls-lR.Z"
# "d--------- 1 owner group 0 May 9 19:45 Softlib"
- # Also WFTPD for MSDOS:
+ # Also WFTPD for MS-DOS:
# "-rwxrwxrwx 1 noone nogroup 322 Aug 19 1996 message.ftp"
# Also NetWare:
# "d [R----F--] supervisor 512 Jan 16 18:53 login"
@@ -132,7 +132,7 @@ def ftpparse(line):
info["name"] = name
return info
- # MSDOS format
+ # MS-DOS format
# 04-27-00 09:09PM
licensed
# 07-18-00 10:16AM pub
# 04-14-00 03:47PM 589 readme.htm
diff --git a/linkcheck/logger/__init__.py b/linkcheck/logger/__init__.py
index 77e1b3b1..77c4b6bc 100644
--- a/linkcheck/logger/__init__.py
+++ b/linkcheck/logger/__init__.py
@@ -304,7 +304,7 @@ class _Logger(abc.ABC):
self.start_fileoutput()
if self.fd is None:
# Happens when aborting threads times out
- log.warn(LOG_CHECK, "writing to unitialized or closed file")
+ log.warn(LOG_CHECK, "writing to uninitialized or closed file")
else:
try:
self.fd.write(s, **args)
diff --git a/linkcheck/logger/failures.py b/linkcheck/logger/failures.py
index d02b5ac3..7f93314f 100644
--- a/linkcheck/logger/failures.py
+++ b/linkcheck/logger/failures.py
@@ -38,7 +38,7 @@ class FailuresLogger(_Logger):
}
def __init__(self, **kwargs):
- """Intialize with old failures data (if found)."""
+ """Initialize with old failures data (if found)."""
blacklist = os.path.join(get_user_data(), "blacklist")
if os.path.isfile(blacklist):
self.LoggerArgs["filename"] = blacklist
diff --git a/linkcheck/robotparser2.py b/linkcheck/robotparser2.py
index fbef5624..35b7721e 100644
--- a/linkcheck/robotparser2.py
+++ b/linkcheck/robotparser2.py
@@ -385,7 +385,7 @@ class Entry:
- our agent applies to this entry
- filename is URL decoded
- Check if given filename is allowed to acces this entry.
+ Check if given filename is allowed to access this entry.
@return: True if allowed, else False
@rtype: bool
diff --git a/linkcheck/strformat.py b/linkcheck/strformat.py
index aced2d42..f16d6e3e 100644
--- a/linkcheck/strformat.py
+++ b/linkcheck/strformat.py
@@ -56,7 +56,7 @@ def unquote(s, matching=False):
@return: if s evaluates to False, return s as is, else return
string with stripped quotes
- @rtype: unquoted string, or s unchanged if it is evaluting to False
+ @rtype: unquoted string, or s unchanged if it is evaluating to False
"""
if not s:
return s
diff --git a/linkcheck/url.py b/linkcheck/url.py
index d09b8933..e6ad1df5 100644
--- a/linkcheck/url.py
+++ b/linkcheck/url.py
@@ -29,7 +29,7 @@ for scheme in ('ldap', 'irc'):
# http://tools.ietf.org/html/rfc2396#section-2.1
# Note that the encoding is not really specified, but most browsers
# encode in UTF-8 when no encoding is specified by the HTTP headers,
-# else they use the page encoding for followed link. See als
+# else they use the page encoding for followed link. See also
# http://code.google.com/p/browsersec/wiki/Part1#Unicode_in_URLs
url_encoding = "utf-8"
@@ -117,7 +117,7 @@ def parse_qsl(qs, encoding, keep_blank_values=0, strict_parsing=0):
errors raise a ValueError exception.
@type strict_parsing: bool
@returns: list of triples (key, value, separator) where key and value
- are the splitted CGI parameter and separator the used separator
+ are the split CGI parameter and separator the used separator
for this CGI parameter which is either a semicolon or an ampersand
@rtype: list of triples
"""
diff --git a/tests/checker/__init__.py b/tests/checker/__init__.py
index d22ed4ac..8a23f62d 100644
--- a/tests/checker/__init__.py
+++ b/tests/checker/__init__.py
@@ -14,7 +14,7 @@
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""
-Define standard test support classes funtional for LinkChecker tests.
+Define standard test support classes functional for LinkChecker tests.
"""
import os
import re
diff --git a/tests/checker/test_mail_bad.py b/tests/checker/test_mail_bad.py
index fb54579e..57623969 100644
--- a/tests/checker/test_mail_bad.py
+++ b/tests/checker/test_mail_bad.py
@@ -33,7 +33,7 @@ class TestMailBad(MailTest):
self.mail_error('mailto:"a""@example.com', cache_key="mailto:a")
self.mail_error('mailto:""a"@example.com', cache_key='mailto:""a"@example.com')
self.mail_error('mailto:"a\\"@example.com', cache_key='mailto:a"@example.com')
- # local part unqouted
+ # local part unquoted
self.mail_error("mailto:.a@example.com")
self.mail_error("mailto:a.@example.com")
self.mail_error("mailto:a..b@example.com")
diff --git a/tests/test_clamav.py b/tests/test_clamav.py
index 2a3c21c7..8e8bbf50 100644
--- a/tests/test_clamav.py
+++ b/tests/test_clamav.py
@@ -34,7 +34,7 @@ class TestClamav(unittest.TestCase):
@need_clamav
def testInfected(self):
- # from the clamav test direcotry: the clamav test file as html data
+ # from the clamav test directory: the clamav test file as html data
data = (
b' licensed",
dict(name="licensed", tryretr=False, trycwd=True),
diff --git a/linkcheck/plugins/sslcertcheck.py b/linkcheck/plugins/sslcertcheck.py
index c143c6e6..981507bf 100644
--- a/linkcheck/plugins/sslcertcheck.py
+++ b/linkcheck/plugins/sslcertcheck.py
@@ -82,16 +82,16 @@ class SslCertificateCheck(_ConnectionPlugin):
try:
notAfter = ssl.cert_time_to_seconds(cert['notAfter'])
except ValueError as msg:
- msg = _('Invalid SSL certficate "notAfter" value %r') % cert['notAfter']
+ msg = _('Invalid SSL certificate "notAfter" value %r') % cert['notAfter']
url_data.add_warning(msg)
return
curTime = time.time()
# Calculate seconds until certifcate expires. Can be negative if
# the certificate is already expired.
secondsValid = notAfter - curTime
args = dict(expire=cert['notAfter'])
if secondsValid < 0:
- msg = _('SSL certficate is expired on %(expire)s.')
+ msg = _('SSL certificate is expired on %(expire)s.')
url_data.add_warning(msg % args)
else:
args['valid'] = strformat.strduration_long(secondsValid)
@@ -82,16 +82,16 @@ class SslCertificateCheck(_ConnectionPlugin):
return
curTime = time.time()
- # Calculate seconds until certifcate expires. Can be negative if
+ # Calculate seconds until certificate expires. Can be negative if
# the certificate is already expired.
secondsValid = notAfter - curTime